@@ -2,12 +2,14 @@ import asyncio
 import base64
 import pickle
 import sys
+from typing import Any, Optional
+
 import pydash
-from typing import Any
+
 from ..constants.queue_constant import QUEUE_NAME
-from ..type_dicts.queue_option_type import QueueOption
 from ..loggers.logger import logger
 from ..tasks.storage import list_tasks
+from ..type_dicts.queue_option_type import QueueOption
 
 
 class Queue:
@@ -15,19 +17,23 @@ class Queue:
 
     def __init__(self, redis: Any, options: QueueOption):
         self.redis = redis
+        self.queue_name = options.get('queue_name') or QUEUE_NAME
         self.concurrency = options.get('concurrency') or 10
         self.max_attempt = options.get('max_attempt') or 3
 
-    async def run(self):
+    async def __get_queue(self):
         if len(self.running_tasks) <= self.concurrency:
-            detail = await self.redis.rpop(QUEUE_NAME)
+            detail = await self.redis.rpop(self.queue_name)
             if detail:
                 task = asyncio.create_task(self.__process_queue(detail))
                 self.running_tasks.add(task)
                 task.add_done_callback(lambda t: self.running_tasks.discard(t))
 
         await asyncio.sleep(2)
-        asyncio.create_task(self.run())
+        asyncio.create_task(self.__get_queue())
+
+    def run(self):
+        asyncio.create_task(self.__get_queue())
 
     def __find_task_handler(self, name: str):
         task = pydash.find(list_tasks, lambda t: t["name"] == name)
@@ -40,7 +46,7 @@ class Queue:
         logger.error(f"Exception {str(exception)}")
         if queue_data["attempt"] > self.max_attempt:
             logger.error(f"Max attempt: {queue_data['attempt']}, please recheck the code")
-            await self.redis.add_to_list("failed_queue", base64.b64encode(pickle.dumps(queue_data)))
+            await self.__add_to_list("failed_queue", base64.b64encode(pickle.dumps(queue_data)))
         else:
             queue_data["attempt"] += 1
             await self.add_queue(queue_data)
@@ -69,23 +75,29 @@ class Queue:
         print("Add to list")
         return await self.redis.lpush(key, value)
 
-    async def add_to_queue(self, name: str, data: Any):
+    async def add_to_queue(self, name: str, data: Any, queue_name: Optional[str] = None):
         if "pytest" in sys.modules:
             return
 
+        if not queue_name:
+            queue_name = self.queue_name
+
         await self.__add_to_list(
-            "queue",
+            queue_name,
             base64.b64encode(pickle.dumps({"name": name, "data": data, "attempt": 0})),
         )
 
-    async def add_class_to_queue(self, name: str, data: Any):
+    async def add_class_to_queue(self, name: str, data: Any, queue_name: Optional[str] = None):
         if "pytest" in sys.modules:
             return
 
+        if not queue_name:
+            queue_name = self.queue_name
+
         await self.__add_to_list(
-            "queue",
+            queue_name,
             base64.b64encode(pickle.dumps({"name": name, "data": data, "attempt": 0})),
         )
 
     async def add_queue(self, options):
-        await self.__add_to_list("queue", base64.b64encode(pickle.dumps(options)))
+        await self.__add_to_list(self.queue_name, base64.b64encode(pickle.dumps(options)))
